@@ -5,14 +5,15 @@ import warnings
 warnings.simplefilter("ignore")
 
 from akerbp.mlops.core import logger, config
-locals().update(config.getenv)
+service_name = config.envs.service_name
 logging=logger.get_logger("mlops_cdf")
 
-service = import_module(f"akerbp.mlops.services.{service_name}").service
-
+from akerbp.mlops.cdf.helpers import log_system_info
+log_system_info()
 
 def handle(data, secrets):
    try:
+      service = import_module(f"akerbp.mlops.services.{service_name}").service
       config.update_cdf_keys(secrets)
       return service(data, secrets)
    except Exception:
