@@ -6,6 +6,7 @@ High level functionality built on top of Cognite's Python SDK
 Most functions require the global cdf client to be set up before using them.
 """
 import time
+import sys
 import os 
 import json
 from shutil import make_archive, unpack_archive
@@ -13,7 +14,6 @@ from shutil import make_archive, unpack_archive
 from cognite.client.exceptions import CogniteNotFoundError, CogniteAPIError
 
 from akerbp.mlops.core import logger, config
-locals().update(config.getenv)
 
 logging=logger.get_logger(name='mlops_cdf')
 
@@ -24,7 +24,7 @@ api_keys=config.api_keys
 def set_up_cdf_client(context='run'):
     """
     Set up the global client used by most helpers. This needs to be called
-    before using any helper. Should be called once with all required keys.
+    before using any helper. 
 
     Input:
       - context: string either 'run' (access to data and functions) or 'deploy'
@@ -89,7 +89,7 @@ def create_function(
         logging.debug(f"Deleted function {function_name}")
     except CogniteNotFoundError:
         pass
-    env_vars = {k.upper():v for k,v in config.getenv.items() if v}
+    env_vars = {k.upper():v for k,v in config.envs_dir.items() if v}
     env_vars.update(dict(DEPLOYMENT_PLATFORM='cdf'))
     function = client.functions.create( 
         name=function_name, 
@@ -302,12 +302,14 @@ def log_system_info():
     """
     Can be called from a handler to log CDF environment information
     """
-    logging.debug(os.popen('python --version').read())
-    logging.debug(os.popen('ls -la *').read())
-    logging.debug(os.popen('pip freeze').read())
+    logging.debug(f"Python version:\n{os.popen('python --version').read()}")
+    logging.debug(f"Python path:\n{sys.path}")
+    logging.debug(f"Current working directory:\n{os.getcwd()}")
+    logging.debug(f"Content:\n{os.popen('ls -la *').read()}")
+    logging.debug(f"Packages:\n{os.popen('pip freeze').read()}")
 
 
-def count_file_versions(
+def count_files(
     external_id_prefix, 
     directory_prefix='/'
 ):
@@ -325,10 +327,13 @@ def count_file_versions(
     return result[0]["count"]
 
 
-def query_file_versions(directory_prefix, external_id_prefix, metadata):
+def query_file_versions(
+    directory_prefix, 
+    external_id_prefix, 
+    metadata, 
+    uploaded=True):
     """
-    Find all file versions that match a query. Only versions that were uploaded
-    are considered
+    Find all file versions that match a query. 
 
     Input:
         -directory_prefix
@@ -343,7 +348,7 @@ def query_file_versions(directory_prefix, external_id_prefix, metadata):
         directory_prefix=directory_prefix, 
         external_id_prefix=external_id_prefix,
         metadata=metadata,
-        uploaded=True
+        uploaded=uploaded
     ).to_pandas()
 
     return file_list
