@@ -2,7 +2,6 @@
 
 import logging
 import os
-from os.path import basename
 
 default_format = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
 base_name='main'
@@ -11,15 +10,15 @@ class CDFLogger:
     def __init__(self, base_name):
         self.base_name=base_name
     def debug(self,log):
-        print(f"{self.basename}-DEBUG-{log}")
+        print(f"{self.base_name}-DEBUG-{log}")
     def info(self,log):
-        print(f"{self.basename}-INFO-{log}")
+        print(f"{self.base_name}-INFO-{log}")
     def warning(self,log):
-        print(f"{self.basename}-WARNING-{log}")
+        print(f"{self.base_name}-WARNING-{log}")
     def error(self,log):
-        print(f"{self.basename}-ERROR-{log}")
+        print(f"{self.base_name}-ERROR-{log}")
     def critical(self,log):
-        print(f"{self.basename}-CRITICAL-{log}")
+        print(f"{self.base_name}-CRITICAL-{log}")
 
 
 def get_logger(name=base_name, format=default_format):
@@ -27,7 +26,8 @@ def get_logger(name=base_name, format=default_format):
     Set up a stream logger
     """
     
-    if not os.getenv('COGNITE_API_KEY_FUNCTIONS'): #hacky test for CDF environm.
+    # can't use config module for this one or there would be circular imports
+    if os.getenv("DEPLOYMENT_PLATFORM")=='cdf': 
         return CDFLogger(base_name)
     
     logger = logging.getLogger(name)
