@@ -4,7 +4,7 @@ from akerbp.mlops import __version__ as version
 from akerbp.mlops.core import logger 
 from akerbp.mlops.deployment.helpers import to_folder, replace_string_file
 
-logging=logger.get_logger(name='MLOps')
+logging=logger.get_logger(name='mlops_deployment')
 
 
 def setup_pipeline(folder_path='.'):
