@@ -4,7 +4,7 @@ import os
 
 import akerbp.mlops.cdf.helpers as cdf
 from akerbp.mlops.core import config, logger
-locals().update(config.getenv)
+env = config.envs.env
 logging=logger.get_logger(name='MLOps')
 
 
@@ -39,8 +39,13 @@ def upload_new_model_version(model_name, env, folder, metadata):
         - model metadata (dictionary)
     """
 
-    filter = f"{model_name}/{env}/"
-    version = cdf.count_file_versions(filter, directory_prefix='/mlops') + 1
+    file_list = cdf.query_file_versions(
+        f"{model_name}/{env}/", 
+        directory_prefix='/mlops', 
+        uploaded=None # count any file
+    )
+    latest_v = file_list.metadata.apply(lambda d:int(d["version"])).max()
+    version = latest_v + 1
     if "version" in metadata:
         logging.error(
             "Metadata should not contain a 'version' key. "
